#!/bin/bash

[ `pidof -x cleaning_space.bash | wc -w` -gt 3 ] && { logger -t [$0] "SPACE CLEANING: Another process already running. Wait..."; exit 0; }

mapArr=(
    "CDR CSV:/mnt/cdrcsv"
    "%CDR SQLite:/mnt/cdr"
    "%Faxes:/mnt/faxes"
    "%Backups:/mnt/backups"
    "%CTI:/mnt/cticonnect"
    "%Voicemail:/dev/shm/var/spool/callweaver/voicemail"
    "%Call recording:/dev/shm/var/spool/callweaver/monitor"
    "%Call generation:/dev/shm/var/spool/callweaver/outgoing"
)

# prepare list of the mount points
for item in "${mapArr[@]}"; do
    item=$(echo $item | sed -e 's/%/\n/g' | awk -F ":" '{print $2}' | xargs)
    list=$( echo -e "$list$item|" )
done
list="$( echo -e $list | sed -e 's/|$//' )"

MOUNTS=$( timeout 10 df -Pha | egrep -w "$list" | awk '{print $6,$5}' )
FLAG="0"

function getName(){
    local mpoint=$1
    echo ${mapArr[*]} | sed -e 's/%/\n/g' | grep -w "${mpoint}" | awk -F ":" '{print $1}'
}

SEND_MAIL() {
local MAIL_FLAG='/tmp/mail_space_notify'

if [ -f "$MAIL_FLAG" ]; then
  [ "$(($(date +%s) - $(stat -c %Y "$MAIL_FLAG")))" -ge "7200" ] && >$MAIL_FLAG || return 404
else
  >$MAIL_FLAG
fi

local MAIL_CONFIG='/etc/companies.d/0/msmtprc'
local PBX_NAME="$(cat /etc/hostname)"
local FROM="$(awk '/from/{print $2}' $MAIL_CONFIG)"
local MAIL_ADMIN="$(ldapsearch -xLLL -h localhost -b "dc=wildix" -D "cn=admin,dc=wildix" -w "wildix" "(&(objectClass=wPerson)(userKind=admin)(cn=admin))" mail | awk '/mail/{print $2}')"

  # check mail password and admin mail
[ ! "$MAIL_ADMIN" ] || [ ! "$(awk '/password/{print $2}' $MAIL_CONFIG)" ] && { logger -t [$0] "SEND_MAIL ERROR: Send email error (not set password or admin email) about disk space more then 10% for ${1} "; return 404; }

  # check from
[ ! "$FROM" ] && FROM="no-reply@wildix.com"

  # send email
parts=`echo ${1} |sed 's/:/\\\n/g'`
mailbody="The following points have disk space less than 10%:\n\n ${parts} \nPlease clear the space for the correct operation of the system."
/usr/sbin/sendemail.php --type="default" --body="`echo -e $mailbody`" --subject="Free disk space problem on $PBX_NAME.wildixin.com" --to=$MAIL_ADMIN

if [ $? -eq "0" ];then
  logger -t [$0] "SEND_MAIL SUCCESS: Notification has been sent to ${MAIL_ADMIN} about the disk space less then 10% for ${1}";
else
  logger -t [$0] "SEND_MAIL ERROR: Notification hasn't been delivered due to error to ${MAIL_ADMIN} about the disk space less then 10% for ${1}";
fi
}

REMOVE() {
if [ ${MOUNTPOINT} = "/dev/shm/var/spool/callweaver/monitor" ];then
  MOUNTPOINT_SIZE=$(df ${MOUNTPOINT} | tail -n 1 | awk '{print $2}')
  FILE="*.mp3$|*.wav$"

    if [ ${MOUNTPOINT_SIZE} -le 2048000 ]; then
      COUNT_FILE="80"
      LIMIT_DELETE="120"
    elif [ ${MOUNTPOINT_SIZE} -ge 2048000 ]; then
          COUNT_FILE="400"
          LIMIT_DELETE="600"
  fi

  elif [ ${MOUNTPOINT} = "/dev/shm/var/spool/callweaver/voicemail" ];then
  MOUNTPOINT_SIZE=$(df ${MOUNTPOINT} | tail -n 1 | awk '{print $2}')
  FILE="*.mp3$|*.wav$"

        if [ ${MOUNTPOINT_SIZE} -le 2048000 ]; then
                COUNT_FILE="80"
                LIMIT_DELETE="120"
        elif [ ${MOUNTPOINT_SIZE} -ge 2048000 ]; then
                COUNT_FILE="400"
                LIMIT_DELETE="600"
        fi

  elif [ ${MOUNTPOINT} = "/dev/shm/var/spool/callweaver/voicemail/*/Old" ];then
  MOUNTPOINT_SIZE=$(df ${MOUNTPOINT} | tail -n 1 | awk '{print $2}')
  FILE="*.alaw$"

        if [ ${MOUNTPOINT_SIZE} -le 2048000 ]; then
                COUNT_FILE="80"
                LIMIT_DELETE="120"
        elif [ ${MOUNTPOINT_SIZE} -ge 2048000 ]; then
                COUNT_FILE="400"
                LIMIT_DELETE="600"
        fi

  elif [ ${MOUNTPOINT} = "/mnt/faxes" ];then
  MOUNTPOINT_SIZE=$(df ${MOUNTPOINT} | tail -n 1 | awk '{print $2}')
  FILE="*.tiff$|*.pdf$"

        if [ ${MOUNTPOINT_SIZE} -le 2048000 ]; then
                COUNT_FILE="60"
                LIMIT_DELETE="120"
        elif [ ${MOUNTPOINT_SIZE} -ge 2048000 ]; then
                COUNT_FILE="300"
                LIMIT_DELETE="600"
        fi

  elif [ ${MOUNTPOINT} = "/mnt/backups" ];then
  MOUNTPOINT_SIZE=$(df ${MOUNTPOINT} | tail -n 1 | awk '{print $2}')
  FILE="*.tar.gz$"

        if [ ${MOUNTPOINT_SIZE} -le 2048000 ]; then
                COUNT_FILE="1"
                LIMIT_DELETE="10"
        elif [ ${MOUNTPOINT_SIZE} -ge 2048000 ]; then
                COUNT_FILE="2"
                LIMIT_DELETE="20"
        fi
fi

PREPARE_REMOVE=$( find ${MOUNTPOINT} -type f -printf "%T@ %p\n" | sort -n | egrep  "${FILE}" | awk '{print $2}' )
if [ $? -eq 0 ] && [ "$( echo "${PREPARE_REMOVE}" | wc -l )" -gt "${LIMIT_DELETE}" ]
then
  REMOVE=$( echo "${PREPARE_REMOVE}" | head -n ${COUNT_FILE} )
  logger -t [$0] "REMOVE_FILE INFO: In ${MOUNTPOINT} files will be removed: ${REMOVE} ";
  echo "${REMOVE}" | xargs rm -f  {}
  find ${MOUNTPOINT} -type d -empty -not -path '*/uploads*' -not -path '*/invoices*' -not -path '*/lost+found*' -not -path '*/traces*' -delete
fi
}

if [ $( echo "${MOUNTS}" | awk '{print $2}' | tr -d '%' | sort -rn | head -n 1 ) -ge "85" ]
then

  while read CHECK_MOUNTS
  do
  MOUNTPOINT=$( echo "${CHECK_MOUNTS}" | awk '{print $1}' )
  mountName=$(getName $MOUNTPOINT);
  USAGE_PERCENT=$( echo "${CHECK_MOUNTS}" | awk '{print $2}' | tr -d '%' )

      case "${USAGE_PERCENT}" in
          9[0-4])
            MAIL_MSG=$( echo -e "${MAIL_MSG}\n ${mountName}:" )
            FLAG="1"
          ;;

          9[5-9]|100)
             REMOVE;
          ;;

      esac
  done <<< "${MOUNTS}"

if [ "${FLAG}" = "1" ]
  then
    SEND_MAIL "${MAIL_MSG}"
fi

fi